/* ver.B.b17(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"nig2svg",
	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
	"ver.B.b17(BLAZE)",
	2008,1,11,
	0,
	"nigmas to svg format converter ",
};

